Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Meta ¶
Meta is a concurrency safe singly-linked list holding key-value pairs, optimized for safety and low memory usage. Under the hood it acts similarly to how standard library context values are stored. You should not regularly rely on fetching / setting values in this, instead caching values yourself.
Click to show internal directories.
Click to hide internal directories.